summaryrefslogtreecommitdiffhomepage
path: root/dev/Boot/src
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal.elmahrouss@icloud.com>2025-01-01 09:46:43 +0100
committerAmlal El Mahrouss <amlal.elmahrouss@icloud.com>2025-01-01 09:46:43 +0100
commitad97dd0ac528b837d14e9236369c823dec66aea8 (patch)
treef09a1dfa53d5290ecf99d6e9910cfeb6816ce55a /dev/Boot/src
parent9cbc1ba661f6c396dbddce05c1d8881a605defdd (diff)
META: Not very important refactor, just see details.
Signed-off-by: Amlal El Mahrouss <amlal.elmahrouss@icloud.com>
Diffstat (limited to 'dev/Boot/src')
-rw-r--r--dev/Boot/src/HEL/AMD64/BootMain.cc28
-rw-r--r--dev/Boot/src/Root/TQ/OSFont.ttf (renamed from dev/Boot/src/Root/zka/fntkrnl.ttf)bin42752 -> 42752 bytes
2 files changed, 14 insertions, 14 deletions
diff --git a/dev/Boot/src/Root/zka/fntkrnl.ttf b/dev/Boot/src/Root/TQ/OSFont.ttf
index e9a6dbb0..e9a6dbb0 100644
--- a/dev/Boot/src/Root/zka/fntkrnl.ttf
+++ b/dev/Boot/src/Root/TQ/OSFont.ttf
Binary files differ
diff --git a/dev/Boot/src/HEL/AMD64/BootMain.cc b/dev/Boot/src/HEL/AMD64/BootMain.cc
index f28dfd70..b927b4f1 100644
--- a/dev/Boot/src/HEL/AMD64/BootMain.cc
+++ b/dev/Boot/src/HEL/AMD64/BootMain.cc
@@ -78,13 +78,13 @@ EXTERN_C Void boot_write_cr3(VoidPtr new_cr3);
EXTERN EfiBootServices* BS;
/// @brief Main EFI entrypoint.
/// @param ImageHandle Handle of this image.
/// @param SystemTable The system table of it.
/// @return nothing, never returns.
-EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr ImageHandle,
- EfiSystemTable* SystemTable)
+EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr image_handle,
+ EfiSystemTable* sys_table)
{
- InitEFI(SystemTable); ///! Init the EFI library.
+ InitEFI(sys_table); ///! Init the EFI library.
HEL::BootInfoHeader* handover_hdr =
new HEL::BootInfoHeader();
@@ -99,11 +99,11 @@ EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr ImageHandle,
if (!boot_init_fb())
return 1; ///! Init the GOP.
- for (SizeT index_vt = 0; index_vt < SystemTable->NumberOfTableEntries;
+ for (SizeT index_vt = 0; index_vt < sys_table->NumberOfTableEntries;
++index_vt)
{
Char* vendor_table = reinterpret_cast<Char*>(
- SystemTable->ConfigurationTable[index_vt].VendorTable);
+ sys_table->ConfigurationTable[index_vt].VendorTable);
// ACPI's 'RSD PTR', which contains the ACPI SDT (MADT, FACP...)
if (vendor_table[0] == 'R' && vendor_table[1] == 'S' &&
@@ -203,7 +203,7 @@ EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr ImageHandle,
handover_hdr->f_FirmwareCustomTables[0] = (VoidPtr)BS;
handover_hdr->f_FirmwareCustomTables[1] = (VoidPtr)ST;
- Boot::BFileReader reader_syschk(L"syschk.sys", ImageHandle);
+ Boot::BFileReader reader_syschk(L"syschk.sys", image_handle);
reader_syschk.ReadAll(0);
Boot::BThread* syschk_thread = nullptr;
@@ -247,21 +247,21 @@ EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr ImageHandle,
handover_hdr->f_FirmwareCustomTables[0] = nullptr;
handover_hdr->f_FirmwareCustomTables[1] = nullptr;
- handover_hdr->f_FirmwareVendorLen = Boot::BStrLen(SystemTable->FirmwareVendor);
+ handover_hdr->f_FirmwareVendorLen = Boot::BStrLen(sys_table->FirmwareVendor);
handover_hdr->f_Magic = kHandoverMagic;
handover_hdr->f_Version = kHandoverVersion;
// Provide fimware vendor name.
- Boot::BCopyMem(handover_hdr->f_FirmwareVendorName, SystemTable->FirmwareVendor,
+ Boot::BCopyMem(handover_hdr->f_FirmwareVendorName, sys_table->FirmwareVendor,
handover_hdr->f_FirmwareVendorLen);
- handover_hdr->f_FirmwareVendorLen = Boot::BStrLen(SystemTable->FirmwareVendor);
+ handover_hdr->f_FirmwareVendorLen = Boot::BStrLen(sys_table->FirmwareVendor);
// Assign to global 'kHandoverHeader'.
- Boot::BFileReader reader_kernel(L"minoskrnl.exe", ImageHandle);
+ Boot::BFileReader reader_kernel(L"minoskrnl.exe", image_handle);
reader_kernel.ReadAll(0);
@@ -286,7 +286,7 @@ EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr ImageHandle,
EFI::Stop();
}
- Boot::BFileReader ttf_font(L"zka\\fntkrnl.ttf", ImageHandle);
+ Boot::BFileReader ttf_font(L"TQ\\OSFont.ttf", image_handle);
ttf_font.ReadAll(0);
@@ -305,7 +305,7 @@ EFI_EXTERN_C EFI_API Int32 Main(EfiHandlePtr ImageHandle,
EFI::Stop();
}
- EFI::ExitBootServices(map_key, ImageHandle);
+ EFI::ExitBootServices(map_key, image_handle);
// ---------------------------------------------------- //
// Finally load the OS kernel.
@@ -78,13 +78,13 @@ EXTERN_C Void boot_write_cr3(VoidPtr new_cr3);
EXTERN EfiBootServices* BS;
/// @brief Main EFI entrypoint.
-/// @param ImageHandle Handle of this image.
-/// @param SystemTable The system table of it.
+/// @param image_handle Handle of this image.
+/// @param sys_table The system table of it.
/// @return nothing, never returns.